@@ -1,4 +1,4 @@
-from sym.cli.helpers import util
+from sym.shared.cli.helpers import util
 
 
 def import_all():
