@@ -15,4 +15,4 @@ from sym.flow.cli.helpers.global_options import GlobalOptions
 def config_set(options: GlobalOptions, key: str, value: str) -> None:
     """Set a config value in your local Sym Flow config file"""
     # For internal use only
-    raise click.UsageError("The ser operation is not currently supported.")
+    raise click.UsageError("The set operation is not currently supported.")
