@@ -1,5 +1,5 @@
 import click
-from sym.cli.helpers.sym_group import SymGroup
+from sym.shared.cli.helpers.sym_group import SymGroup
 
 from sym.flow.cli.helpers.global_options import GlobalOptions
 
