@@ -5,7 +5,7 @@ from urllib.parse import quote
 from uuid import uuid4
 
 import boto3
-from sym.cli.helpers.boto import intercept_boto_errors
+from sym.shared.cli.helpers.boto import make_intercept_boto_errors
 
 from sym.flow.cli.helpers.constants import (
     DROPBOX_BUCKET,
@@ -13,6 +13,8 @@ from sym.flow.cli.helpers.constants import (
     WRITE_ONLY_AWS_SECRET_ACCESS_KEY,
 )
 
+intercept_boto_errors = make_intercept_boto_errors({})
+
 
 def path_for_uploading(path: Path, ext: str) -> Tuple[str, str]:
     """Create a file name for the upload that includes the full
