@@ -3,8 +3,9 @@ import tempfile
 from io import BytesIO
 from pathlib import Path
 
-from sym.cli.decorators import require_bins, run_subprocess
-from sym.cli.helpers.global_options import GlobalOptions
+from sym.shared.cli.decorators import require_bins, run_subprocess
+
+from sym.flow.cli.helpers.global_options import GlobalOptions
 
 from .boto import path_for_uploading, put_public_fileobj
 
