@@ -10,6 +10,7 @@ class AuthHTTPRequestHandler(BaseHTTPRequestHandler):
     options: ClassVar[GlobalOptions]
     state: ClassVar[str]
     auth_code: ClassVar[str]
+    error_message: ClassVar[str]
 
     def log_message(self, format, *args):
         ...
@@ -18,29 +19,33 @@ class AuthHTTPRequestHandler(BaseHTTPRequestHandler):
         parsed = parse.urlparse(self.path)
         qs = parse.parse_qs(parsed.query)
 
-        if not "code" in qs:
-            self.send_error(401, explain="Missing code in query")
-            return
-
-        if not "state" in qs:
-            self.send_error(401, explain="Missing state in query")
-            return
-
-        [returned_state] = qs["state"]
-        if not returned_state == self.__class__.state:
+        if qs.get("error_description"):
+            error_message = qs["error_description"][0]
+        elif not qs.get("code"):
+            error_message = "Missing code in query"
+        elif not qs.get("state"):
+            error_message = "Missing state in query"
+        elif not qs["state"][0] == self.__class__.state:
             self.__class__.options.dprint(
-                f"Invalid state. Found: {returned_state}, expected: {self.__class__.state}."
+                f"Invalid state. Found: {qs['state'][0]}, expected: {self.__class__.state}."
             )
-            self.send_error(401, explain="Invalid state")
-            return
+            error_message = "Invalid state"
+        else:
+            error_message = None
 
-        [returned_code] = qs["code"]
+        if error_message:
+            query = parse.urlencode({"message": error_message})
+            self.send_response(301)
+            self.send_header("Location", f"https://static.symops.com/cli/error?{query}")
+            self.end_headers()
+            self.__class__.error_message = error_message
+            return
 
         self.send_response(301)
         self.send_header("Location", "https://static.symops.com/cli/login")
         self.end_headers()
 
-        self.__class__.auth_code = returned_code
+        self.__class__.auth_code = qs["code"][0]
 
 
 def make_handler(options: GlobalOptions, state: str) -> Type[AuthHTTPRequestHandler]:
