@@ -2,7 +2,7 @@ import uuid
 import webbrowser
 from abc import ABC, abstractmethod
 from http.server import HTTPServer
-from typing import Tuple
+from typing import Optional, Tuple
 
 import click
 import pkce
@@ -23,9 +23,9 @@ class LoginFlow(ABC):
         pass
 
     @classmethod
-    def get_login_flow(cls, email: str, browser: bool, port: int) -> "LoginFlow":
+    def get_login_flow(cls, browser: bool, port: int) -> "LoginFlow":
         if not browser:
-            return PasswordPromptFlow(email)
+            return PasswordPromptFlow()
         else:
             return BrowserRedirectFlow(port)
 
@@ -40,17 +40,12 @@ class PasswordPromptFlow(LoginFlow):
     https://auth0.com/docs/flows/call-your-api-using-resource-owner-password-flow
     """
 
-    email: str
-
-    def __init__(self, email: str):
-        self.email = email
-
     def login(self, options: GlobalOptions, org: Organization) -> AuthToken:
-        creds = self.prompt_for_user_credentials(self.email)
+        creds = self.prompt_for_user_credentials()
         return self.login_with_user_creds(options, creds, org)
 
-    def prompt_for_user_credentials(self, email: str) -> UserCredentials:
-        username = click.prompt("Please enter your username", type=str, default=email)
+    def prompt_for_user_credentials(self) -> UserCredentials:
+        username = click.prompt("Please enter your username", type=str)
         password = click.prompt("Please enter your password", type=str, hide_input=True)
         return UserCredentials(username, password)
 
@@ -65,7 +60,7 @@ class PasswordPromptFlow(LoginFlow):
             "password": creds.password,
             "audience": options.api_url,
             "scope": " ".join(DEFAULT_SCOPES),
-            "client_id": org["client_id"],
+            "client_id": org.client_id,
         }
         headers = {"content-type": "application/x-www-form-urlencoded"}
         url = f"{options.auth_url}/oauth/token"
@@ -93,10 +88,10 @@ class BrowserRedirectFlow(LoginFlow):
         self.port = port
         self.browser_login_params = None
 
-    def login(self, options: GlobalOptions, org: Organization) -> AuthToken:
+    def login(self, options: GlobalOptions, org: Organization) -> Optional[AuthToken]:
         auth_code, code_verifier = self.get_auth_code(options, org)
         if not auth_code:
-            raise CliError("Unable to get access token from Auth0. Please try again.")
+            return
         return self.get_token_from_code(options, org, auth_code, code_verifier)
 
     @property
@@ -112,7 +107,7 @@ class BrowserRedirectFlow(LoginFlow):
                     raise
                 options.dprint(f"Port {port} in use, trying to increment...")
 
-    def wait_for_code(self, state: str, options: GlobalOptions):
+    def wait_for_code(self, state: str, options: GlobalOptions) -> Optional[str]:
         """
         Starts a server and waits for a request that contains an auth code.
         """
@@ -120,7 +115,23 @@ class BrowserRedirectFlow(LoginFlow):
         with self._new_server(options, handler) as httpd:
             options.dprint(f"Waiting for an auth code at {self.redirect_url}")
             httpd.handle_request()
-            return getattr(handler, "auth_code", None)
+
+            # Bubble up any error message received during handling of the request from the HTTPServer.
+            if error_message := getattr(handler, "error_message", None):
+                # If we know the problem is that the user just signed up (and therefore their email is not validated),
+                # give them a non-error message.
+                if "complete sign up" in error_message:
+                    click.secho(error_message, fg="cyan")
+                    return
+                else:
+                    # Otherwise, raise the error message that we got from the HTTP response.
+                    raise CliError(error_message)
+
+            # We didn't get an auth_code, but the HTTPServer didn't register any errors.
+            if not (auth_code := getattr(handler, "auth_code", None)):
+                raise CliError("Unable to get access token from Auth0. Please try again.")
+
+            return auth_code
 
     def gen_state(self) -> str:
         return str(uuid.uuid4())
@@ -136,7 +147,7 @@ class BrowserRedirectFlow(LoginFlow):
             query_params = "&".join(
                 [
                     "response_type=code",
-                    f"client_id={org['client_id']}",
+                    f"client_id={org.client_id}",
                     "code_challenge_method=S256",
                     f"code_challenge={code_challenge}",
                     f"redirect_uri={self.redirect_url}",
@@ -180,7 +191,7 @@ class BrowserRedirectFlow(LoginFlow):
         """
         data = {
             "grant_type": "authorization_code",
-            "client_id": org.get("client_id"),
+            "client_id": org.client_id,
             "code_verifier": code_verifier,
             "code": auth_code,
             "redirect_uri": self.redirect_url,
