@@ -1,7 +1,7 @@
 from unittest.mock import patch
 from uuid import UUID
 
-from sym.cli.tests.helpers.capture import CaptureCommand
+from sym.shared.cli.tests.helpers.capture import CaptureCommand
 
 from sym.flow.cli.symflow import symflow as click_command
 from sym.flow.cli.tests.helpers.sandbox import Sandbox
