@@ -11,7 +11,7 @@ from sym.flow.cli.models import AuthToken, Organization
 from sym.flow.cli.symflow import symflow as click_command
 from sym.flow.cli.tests.conftest import get_mock_response
 
-TEST_LOGIN_EMAIL = "ci@symops.io"
+TEST_LOGIN_ORG_SLUG = "test"
 
 
 def mock_login_flow(result: Union[AuthToken, CliError]):
@@ -50,13 +50,13 @@ login_test_org = Organization(slug="test", client_id="12345abc")
 def login_tester(click_setup):
     def tester(
         login_flow: LoginFlow,
-        email: str,
+        org_slug: str,
         expected_output: List[str],
         success: bool = True,
     ):
         with patch.object(LoginFlow, "get_login_flow", return_value=login_flow):
             with click_setup() as runner:
-                result = runner.invoke(click_command, ["login", "--email", email])
+                result = runner.invoke(click_command, ["login", "--org-slug", org_slug])
                 print(result.output)
                 for expected_str in expected_output:
                     assert expected_str in result.output
@@ -69,96 +69,62 @@ def login_tester(click_setup):
 
 
 @patch(
-    "sym.flow.cli.helpers.api.SymAPI.get_organization_from_email",
+    "sym.flow.cli.helpers.api.SymAPI.get_organization_from_slug",
     return_value=login_test_org,
 )
-@patch(
-    "sym.flow.cli.helpers.api.SymAPI.verify_login",
-    return_value=True,
-)
-def test_login_ok(mock_verify_login, mock_get_org, login_flow, login_tester):
-    expected_output = ["Org: test", "Login succeeded"]
+def test_login_ok(mock_get_org, login_flow, login_tester):
     login_tester(
         login_flow=login_flow,
-        email=TEST_LOGIN_EMAIL,
+        org_slug=TEST_LOGIN_ORG_SLUG,
         success=True,
-        expected_output=expected_output,
+        expected_output=["Login succeeded"],
     )
 
-    mock_get_org.assert_called_once_with(TEST_LOGIN_EMAIL)
-    mock_verify_login.assert_called_once_with(TEST_LOGIN_EMAIL)
+    mock_get_org.assert_called_once_with(TEST_LOGIN_ORG_SLUG)
 
 
 @patch(
-    "sym.flow.cli.helpers.api.SymAPI.get_organization_from_email",
+    "sym.flow.cli.helpers.api.SymAPI.get_organization_from_slug",
     return_value=login_test_org,
 )
-def test_login_login_error(mock_get_org, login_flow_login_error, login_tester):
-    expected_output = [
-        "Org: test",
-        "Error logging in: test",
-    ]
+def test_login_login_error(_, login_flow_login_error, login_tester):
     login_tester(
         login_flow=login_flow_login_error,
-        email=TEST_LOGIN_EMAIL,
+        org_slug=TEST_LOGIN_ORG_SLUG,
         success=False,
-        expected_output=expected_output,
+        expected_output=[f"Error logging in: {TEST_LOGIN_ORG_SLUG}"],
     )
 
 
 @patch(
-    "sym.flow.cli.helpers.api.SymAPI.get_organization_from_email",
+    "sym.flow.cli.helpers.api.SymAPI.get_organization_from_slug",
     return_value=login_test_org,
 )
-def test_login_invalid_token_error(
-    mock_get_org, login_flow_invalid_token_error, login_tester
-):
-    expected_output = [
-        "Org: test",
-        "Unable to parse token: test",
-    ]
+def test_login_invalid_token_error(_, login_flow_invalid_token_error, login_tester):
     login_tester(
         login_flow=login_flow_invalid_token_error,
-        email=TEST_LOGIN_EMAIL,
+        org_slug=TEST_LOGIN_ORG_SLUG,
         success=False,
-        expected_output=expected_output,
+        expected_output=[f"Unable to parse token: {TEST_LOGIN_ORG_SLUG}"],
     )
 
 
 @patch(
-    "sym.flow.cli.helpers.api.SymRESTClient.get",
-    return_value=(get_mock_response(200), "test-request-id"),
+    "requests.request",
+    return_value=(
+        get_mock_response(
+            404,
+            {
+                "message": f"No Organization with the slug {TEST_LOGIN_ORG_SLUG} was found."
+            },
+        )
+    ),
 )
-def test_login_unknown_org(mock_api_get, login_flow, login_tester):
-    expected_output = [
-        f"Unknown organization for email: {TEST_LOGIN_EMAIL}",
-    ]
+@patch("sym.flow.cli.helpers.rest.SymRESTClient.make_headers", return_value={})
+def test_login_unknown_org(_, __, login_flow, login_tester):
     login_tester(
         login_flow=login_flow,
-        email=TEST_LOGIN_EMAIL,
+        org_slug=TEST_LOGIN_ORG_SLUG,
         success=False,
-        expected_output=expected_output,
+        expected_output=[f"No Organization with the slug {TEST_LOGIN_ORG_SLUG}"],
     )
-
-
-@patch(
-    "sym.flow.cli.helpers.api.SymAPI.get_organization_from_email",
-    return_value=login_test_org,
-)
-def test_login_api_verify_failure(mock_get_org, login_flow, login_tester):
-    expected_output = ["Sym could not verify this login"]
-
-    with patch(
-        "sym.flow.cli.helpers.api.SymAPI.verify_login",
-        return_value=False,
-    ) as mock_verify_failed:
-        login_tester(
-            login_flow=login_flow,
-            email=TEST_LOGIN_EMAIL,
-            success=True,  # Return code should only be non-zero if a truly unexpected error occurred
-            expected_output=expected_output,
-        )
-
-        mock_verify_failed.assert_called_once_with(TEST_LOGIN_EMAIL)
-
-    mock_get_org.assert_called_once()
