@@ -23,8 +23,12 @@ def expected_policy_json():
     return _expected_policy_json
 
 
+def _prepare_policy(policy):
+    return sorted(json.loads(policy)["Statement"], key=lambda x: x["Sid"])
+
+
 def assert_policies(policy1, policy2):
-    assert json.loads(policy1) == json.loads(policy2)
+    assert _prepare_policy(policy1) == _prepare_policy(policy2)
 
 
 def test_iam_policies(expected_policy_json):
